@@ -12,6 +12,8 @@ from .models import (
     ChannelModel,
     ChannelStatistics,
     ChannelStatisticsList,
+    DashboardStatusModel,
+    DashboardStatusList,
     EventList,
     EventModel,
     GroupList,
@@ -127,6 +129,20 @@ class MirthAPI:
 
         return channels.channel
 
+    async def channel_statuses(self) -> List[DashboardStatusModel]:
+        """Get a list of all channel statuses on the Mirth instance.
+
+        Returns:
+            List[Channel]: List of Mirth channels
+        """
+        response = await self.get("/channels/statuses")
+
+        statuses = DashboardStatusList.parse_raw(
+            response.text, content_type="xml", force_list=("status",)
+        )
+
+        return statuses.dashboard_status
+
     async def statistics(self) -> List[ChannelStatistics]:
         """Get a list of all channel statistics on the Mirth instance.
 
